# coding: utf-8

"""
Diveplane API

OpenAPI implementation for interacting with the Diveplane API. 
"""

try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from diveplane.openapi.configuration import Configuration


class FeaturePredictionStatsRequest(object):
    """
    Auto-generated OpenAPI type.

    The body of a feature prediction stats request. 
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'action_feature': 'str',
        'robust': 'bool',
        'robust_hyperparameters': 'bool',
        'stats': 'list[str]',
        'weight_feature': 'str'
    }

    attribute_map = {
        'action_feature': 'action_feature',
        'robust': 'robust',
        'robust_hyperparameters': 'robust_hyperparameters',
        'stats': 'stats',
        'weight_feature': 'weight_feature'
    }

    nullable_attributes = [
    ]

    discriminator = None

    def __init__(self, action_feature=None, robust=None, robust_hyperparameters=None, stats=None, weight_feature=None, local_vars_configuration=None):  # noqa: E501
        """FeaturePredictionStatsRequest - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._action_feature = None
        self._robust = None
        self._robust_hyperparameters = None
        self._stats = None
        self._weight_feature = None

        if action_feature is not None:
            self.action_feature = action_feature
        if robust is not None:
            self.robust = robust
        if robust_hyperparameters is not None:
            self.robust_hyperparameters = robust_hyperparameters
        if stats is not None:
            self.stats = stats
        if weight_feature is not None:
            self.weight_feature = weight_feature

    @property
    def action_feature(self):
        """Get the action_feature of this FeaturePredictionStatsRequest.

        When specified, will attempt to return stats that were computed for this specified action_feature. Note: \".targetless\" is the action feature used during targetless optimization. 

        :return: The action_feature of this FeaturePredictionStatsRequest.
        :rtype: str
        """
        return self._action_feature

    @action_feature.setter
    def action_feature(self, action_feature):
        """Set the action_feature of this FeaturePredictionStatsRequest.

        When specified, will attempt to return stats that were computed for this specified action_feature. Note: \".targetless\" is the action feature used during targetless optimization. 

        :param action_feature: The action_feature of this FeaturePredictionStatsRequest.
        :type action_feature: str
        """

        self._action_feature = action_feature

    @property
    def robust(self):
        """Get the robust of this FeaturePredictionStatsRequest.

        When specified, will attempt to return stats that were computed with the specified robust or non-robust type. 

        :return: The robust of this FeaturePredictionStatsRequest.
        :rtype: bool
        """
        return self._robust

    @robust.setter
    def robust(self, robust):
        """Set the robust of this FeaturePredictionStatsRequest.

        When specified, will attempt to return stats that were computed with the specified robust or non-robust type. 

        :param robust: The robust of this FeaturePredictionStatsRequest.
        :type robust: bool
        """

        self._robust = robust

    @property
    def robust_hyperparameters(self):
        """Get the robust_hyperparameters of this FeaturePredictionStatsRequest.

        When specified, will attempt to return stats that were computed using hyperparameters with the specified robust or non-robust type. 

        :return: The robust_hyperparameters of this FeaturePredictionStatsRequest.
        :rtype: bool
        """
        return self._robust_hyperparameters

    @robust_hyperparameters.setter
    def robust_hyperparameters(self, robust_hyperparameters):
        """Set the robust_hyperparameters of this FeaturePredictionStatsRequest.

        When specified, will attempt to return stats that were computed using hyperparameters with the specified robust or non-robust type. 

        :param robust_hyperparameters: The robust_hyperparameters of this FeaturePredictionStatsRequest.
        :type robust_hyperparameters: bool
        """

        self._robust_hyperparameters = robust_hyperparameters

    @property
    def stats(self):
        """Get the stats of this FeaturePredictionStatsRequest.

        Types of stats to output. When unspecified, returns all. 

        :return: The stats of this FeaturePredictionStatsRequest.
        :rtype: list[str]
        """
        return self._stats

    @stats.setter
    def stats(self, stats):
        """Set the stats of this FeaturePredictionStatsRequest.

        Types of stats to output. When unspecified, returns all. 

        :param stats: The stats of this FeaturePredictionStatsRequest.
        :type stats: list[str]
        """
        allowed_values = ["accuracy", "contribution", "mae", "mda", "mda_permutation", "precision", "r2", "recall", "rmse", "spearman_coeff"]  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                not set(stats).issubset(set(allowed_values))):  # noqa: E501
            raise ValueError(
                "Invalid values for `stats` [{0}], must be a subset of [{1}]"  # noqa: E501
                .format(", ".join(map(str, set(stats) - set(allowed_values))),  # noqa: E501
                        ", ".join(map(str, allowed_values)))
            )

        self._stats = stats

    @property
    def weight_feature(self):
        """Get the weight_feature of this FeaturePredictionStatsRequest.

        When specified, will attempt to return stats that were computed using this weight_feature. 

        :return: The weight_feature of this FeaturePredictionStatsRequest.
        :rtype: str
        """
        return self._weight_feature

    @weight_feature.setter
    def weight_feature(self, weight_feature):
        """Set the weight_feature of this FeaturePredictionStatsRequest.

        When specified, will attempt to return stats that were computed using this weight_feature. 

        :param weight_feature: The weight_feature of this FeaturePredictionStatsRequest.
        :type weight_feature: str
        """

        self._weight_feature = weight_feature

    def to_dict(self, serialize=False, exclude_null=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                elif 'exclude_null' in args:
                    return x.to_dict(serialize, exclude_null)
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: convert(x),
                    value
                ))
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], convert(item[1])),
                    value.items()
                ))
            elif value is None and (exclude_null or attr not in self.nullable_attributes):
                continue
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, FeaturePredictionStatsRequest):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, FeaturePredictionStatsRequest):
            return True

        return self.to_dict() != other.to_dict()
